@@ -6,7 +6,7 @@ import jsonschema
 
 try:
     from django.db.models import JSONField
-else:
+except:
     from django.contrib.postgres.fields import JSONField
 
 from django.contrib.staticfiles import finders
