@@ -1,5 +1,7 @@
-from drf_yasg import inspectors
-class ValidatedJSONFieldInspector(inspectors.JSONFieldInspector):
+from drf_yasg.inspectors import JSONFieldInspector
+
+
+class ValidatedJSONFieldInspector(JSONFieldInspector):
 
     def add_manual_fields(self, serializer_or_field, schema):
         """Set fields from the ``swagger_schem_fields`` attribute on the Meta class. This method is called
