@@ -30,7 +30,7 @@ class ValidatedJSONField(serializers.JSONField):
 
 class ValidatedJsonModelSerializerMixin(serializers.ModelSerializer):
 
-    self.__init__(self, *args, **kargs):
+    def __init__(self, *args, **kargs):
         super().__init__(*args, **kargs)
 
         self.serializer_field_mapping[ModelValidatedJSONField] = ValidatedJSONField
